@@ -28,10 +28,4 @@ class BaseSortingStyle(Plugin):
         raise NotImplementedError
 
     def sort(self, entries):
-        entry_dict = dict(
-            (self.sorting_key(entry), entry)
-            for entry in entries
-        )
-        sorted_keys = sorted(entry_dict)
-        sorted_entries = [entry_dict[key] for key in sorted_keys]
-        return sorted_entries
+        return sorted(entries, key=self.sorting_key)
